import sys

if sys.version_info < (3, 7):
    from ._x import X
    from ._y import Y
    from ._z import Z
else:
    from _plotly_utils.importers import relative_import

    __all__, __getattr__, __dir__ = relative_import(
        __name__, [], ["._x.X", "._y.Y", "._z.Z"]
    )
