import _plotly_utils.basevalidators


class LineValidator(_plotly_utils.basevalidators.CompoundValidator):
    def __init__(self, plotly_name="line", parent_name="ohlc", **kwargs):
        super(LineValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            data_class_str=kwargs.pop("data_class_str", "Line"),
            data_docs=kwargs.pop(
                "data_docs",
                """
            dash
                Sets the dash style of lines. Set to a dash
                type string ("solid", "dot", "dash",
                "longdash", "dashdot", or "longdashdot") or a
                dash length list in px (eg "5px,10px,2px,2px").
                Note that this style setting can also be set
                per direction via `increasing.line.dash` and
                `decreasing.line.dash`.
            width
                [object Object] Note that this style setting
                can also be set per direction via
                `increasing.line.width` and
                `decreasing.line.width`.
""",
            ),
            **kwargs
        )
